User Guide - Whombat

Skip to content

# User Guide

## Welcome to Whombat!

We're happy to have you on board with Whombat, the open-source tool for audio annotation with ML in mind. Whether you're just getting started or looking to refine your annotation process, this guide is here to make your work smooth and enjoyable.

Here we you can get more information about how to start your audio annotation work and make best use of this tool.

### Table of Contents

1. Installation
2. Registering Recordings and Managing Datasets
3. Creating Annotation Projects
4. Visualizing and Evaluating Model Predictions
5. Exploration of Data

Feel free to use the handy search bar above to quickly locate the information you need. Additionally, we've curated a FAQ section to address common queries and provide even more insights.

### Searching for Answers

Can't find what you're looking for? No worries! Reach out to us with your questions.